@@ -10,3 +10,8 @@ from .project_services import ProjectService
 from .article_services import ArticleService
 from .expense_services import ExpenseService
 from .financial_year_services import FinancialYearService
+from .invoice_services import InvoiceService
+from .asset_type_services import AssetTypeService
+from .predefined_account_services import PredefinedAccountService
+from .predefined_voucher_series_services import PredefinedVoucherSeriesService
+from .asset_services import AssetService
